pub struct State {
pub namespace_store: Store<Namespace>,
pub kanidm_store: Store<Kanidm>,
pub client: Option<Client>,
/* private fields */
}Expand description
State shared between the controller and the web server
Fields
namespace_store: Store<Namespace>Cache for Namespace resources
kanidm_store: Store<Kanidm>Cache for Kanidm resources
client: Option<Client>Kubernetes client
Implementations
Sourceimpl State
State wrapper around the controller outputs for the web server
impl State
State wrapper around the controller outputs for the web server