pub struct State {
pub namespace_store: Store<Namespace>,
pub kanidm_store: Store<Kanidm>,
pub client: Option<Client>,
/* private fields */
}Expand description
State shared between the controller and the web server
Fields
namespace_store: Store<Namespace>Cache for Namespace resources
kanidm_store: Store<Kanidm>Cache for Kanidm resources
client: Option<Client>Kubernetes client
Implementations
Sourceimpl State
State wrapper around the controller outputs for the web server
impl State
State wrapper around the controller outputs for the web server
pub fn new( registry: Registry, controller_names: &[&'static str], namespace_store: Store<Namespace>, kanidm_store: Store<Kanidm>, client: Option<Client>, ) -> Self
Sourcepub fn to_context<K>(
&self,
client: Client,
controller_id: ControllerId,
) -> Context<K>
pub fn to_context<K>( &self, client: Client, controller_id: ControllerId, ) -> Context<K>
Create a Controller Context that can update State