pub struct ExternalReplicationNode {
pub name: String,
pub hostname: String,
pub port: i32,
pub certificate: SecretKeySelector,
pub _type: ReplicationType,
pub automatic_refresh: bool,
}Fields
name: StringName of the external replication node. This just have internal use.
hostname: StringThe hostname of the external replication node.
port: i32The replication port of the external replication node.
certificate: SecretKeySelectorDefines the secret that contains the identity certificate of the external replication node.
_type: ReplicationTypeDefines the type of replication to use. Defaults to MutualPull.
automatic_refresh: boolSelect external replication node as the primary node. This means that if database conflicts occur the content of the primary will take precedence over the rest of the nodes. Note: just one external replication node or replication group can be selected as primary. Defaults to false.